@@ -16,4 +16,4 @@ ninja -C "${MESON_BUILD_ROOT}" $filelist
 for i in $filelist ; do
 	cp -p "${MESON_BUILD_ROOT}"/$i .
 done
-(TZ=UTC LC_ALL=C date >fetchmail.tarball)
+(echo dist-marker >fetchmail.tarball)
